import pandas as pd 
import pandasgui as pg 
import numpy as np 
import matplotlib.pylab as plt 
from sklearn.metrics import roc_curve
from sklearn.metrics import roc_auc_score

data = pd.read_csv("./annotation_with_prop_scores.csv")


def getFprTpr(df, true_classes, scores):
    dataframe = df[[true_classes, scores ]].dropna()
    true = dataframe[true_classes]
    scores = dataframe[scores]
    fpr, tpr, _ = roc_curve(true, scores, pos_label=1)
    print("AUC = ", roc_auc_score(true, scores))
    return fpr, tpr


fpr_swaat, tpr_swaat = getFprTpr(data, "class", "swaart_proba_score" )
fpr_sift, tpr_sift = getFprTpr(data, "class", "SIFT" )
fpr_cadd, tpr_cadd = getFprTpr(data, "class", "CADD_PHRED" )
fpr_fathmm, tpr_fathmm = getFprTpr(data, "class", "FATHMM_score" )
fpr_polyphen, tpr_polyphen = getFprTpr(data, "class", "PolyPhen" )
fpr_provean, tpr_provean = getFprTpr(data, "class", "PROVEAN_score" )
fpr_svn, tpr_svn = getFprTpr(data, "class", "MetaSVM_score" )

plt.figure(figsize=(5,5))

plt.step(fpr_sift, tpr_sift, marker="p", linewidth=1, color = '#4d4d4dff', label= "SIFT (AUC=0.26)")
plt.step(fpr_cadd, tpr_cadd, marker="D", linewidth=1, color = '#4d4d4dff', label= "CADD (AUC=0.61)")
plt.step(fpr_fathmm, tpr_fathmm, marker=">", linewidth=1, color = '#4d4d4dff', label= "FATHMM (AUC=0.63)")
plt.step(fpr_polyphen, tpr_polyphen,  marker="d", linewidth=1, color = '#4d4d4dff', label= "PolyPhen-2 (AUC=0.76)")
plt.step(fpr_provean, tpr_provean, marker="h", linewidth=1, color = '#4d4d4dff', label= "PROVEAN (AUC=0.28)")
plt.step(fpr_svn, tpr_svn, marker="$+$", linewidth=1, color = '#4d4d4dff', label= "MetaSVM (AUC=0.53)")
plt.step(fpr_swaat, tpr_swaat, linewidth=3, color = '#008397ff', label= "SWAAT (AUC=0.75)")
plt.plot([0,1],[0,1], "--", color="red",alpha=0.6)

plt.xlabel("False Positive Rate", fontsize=13)
plt.ylabel("True Positive Rate", fontsize=13)

plt.legend(bbox_to_anchor=(1,1), loc="upper left")

plt.savefig("roc_swaat.svg")